;+
; NAME: H5REXPAND
;
; PURPOSE:
;   This subroutine expands variables in a given HDF5 file or set of files.
;
; CATEGORY:
;   Data processing.
;
; CALLING SEQUENCE:
;   H5EXPANDFILE, IDIR, ITYP, INUM, ODIR, OTYP, ONUM
;
; INPUTS:
;   IDIR, ITYP, INUM:
;    the directory, type and number of input file/files.
;
;   ODIR, OTYP, ONUM:
;    the directory, type and number of output file/files.
;
; OPTIONAL INPUT PARAMETERS:
;
; KEYWORD INPUT PARAMETERS:
;   PRINT:  Optional keyword increasing verbosity of this subroutine.
;
;
pro h5expand, idir, ityp, inum, odir, otyp, onum, print = p, _extra = extra

; generate input filename
;
  ichk = 0
  ifile = h5filename(idir,ityp,inum,ichk)

  ofile = h5filename(odir,otyp,onum,ichk)

  if (strcmp(ifile,ofile) eq 1) then $
    message, 'The input and output files are the same! Please correct!'

; check it the file is really written in HDF5 format
;
  if (not h5f_is_hdf5(ifile)) then $
    message, 'The file ' + ifile + ' is not in HDF5 format or does not exist!'

; gather some information required for the processing procedure
;
  h5info, ifile, nchunks = nchks, pdim = pm

; print info
;
  if (keyword_set(p)) then begin
    print, 'num. of chunks             :', nchks
    print, 'chunk distribution         :', pm
  endif

; process all chunks
;
  for ichk = 0, nchks - 1 do $
    h5expandfile, idir, ityp, inum, odir, otyp, onum, ichk, print = p, _extra = extra

end